# Build Information

_provided by [glsr-present](https://pypi.org/project/glsr-present/) 0.3.6_

[ncw](https://gitlab.com/blackstream-x/ncw)
built with pipeline
[1843740011](https://gitlab.com/blackstream-x/ncw/-/pipelines/1843740011)
(build started 2025-05-29T23:13:29Z)

